@@ -24,7 +24,7 @@ sub check_message {
 
 sub prep_environment {
     my @ack_args   = qw( ACK_OPTIONS ACKRC ACK_PAGER HOME ACK_COLOR_MATCH ACK_COLOR_FILENAME ACK_COLOR_LINE );
-    my @taint_args = qw( PATH CDPATH IFS );
+    my @taint_args = qw( PATH CDPATH IFS ENV );
     delete @ENV{ @ack_args, @taint_args };
 
     if ( is_windows() ) {
@@ -246,7 +246,7 @@ sub run_cmd {
             my $input_command = Win32::ShellQuote::quote_system_string(@{$input});
             $cmd = "$input_command | $cmd";
         }
-        system( $cmd ) or die "system( $cmd ) failed: $!";
+        system( $cmd );
         close STDOUT;
         close STDERR;
         open(STDOUT, ">&SAVEOUT") or die "Can't restore STDOUT: $!";
